/**************************************************************************
Copyright 2004 Fisher-Rosemount Systems, Inc. - All rights reserved

Description: Global AMS device resource identifiers.

$Revision: 5 $
*****************************************************************************/
#ifndef __FMSDEVRC_H
#define __FMSDEVRC_H

//////////////////////////////////////////////////////////////////////////////
// GENERAL DEVICE IDs
// Generic device resource IDs
#define IDA_DEVICE            100   // Device accelerator table
#define IDB_DEVICE            101   // Device bitmap
#define IDI_DEVICE            102   // Device icon (Standard 32x32 and 16x16)
#define IDS_MANUFACTURER      103   // Device manufacturer string
#define IDS_TYPE              104   // Device type string
#define IDS_REVISION          105   // Device revision string


//////////////////////////////////////////////////////////////////////////////
// DEVICE RESOURCE TEMPLATE IDs
// Device Process Variables (faceplate) display identifiers.
#define IDD_FACEPLATE         300   // Device faceplate dialog template
#define IDS_FACEPLATE         301   // Faceplate template name base string

// Device configure display identifier and offsets (the tab labels and the page
// template names).
// Note that the first config template ID is 5010.
#define IDD_CONFIGDISPLAY    5000   // Device configuration initial template
#define IDS_CONFIGDISPLAY    5001   // Config template name base string
#define IDD_CONFIG_PAGE        10   // Add to above for start of page(s)
#define IDS_CONFIG_LABEL     7000   // ...to config ID for tab label

// Device status display identifier offsets (the tab labels and the page
// template names).
// Note that status display pages are numbered from 0..., j, ...N-1.
// Since there are a possible 10 transmitter modes, we could actually have as
// many as 1900 dialog templates and 1900 tab labels in a single device.
// Note that the first status template ID is 1010.
#define IDD_STATUSDISPLAY    1000   // Device configuration initial template
#define IDS_STATUSDISPLAY    1001   // Config template name base string
#define IDD_STATUS_PAGE        10   // Add to above for start of page(s)
#define IDS_STATUS_LABEL     3000   // ...to config ID for tab label

// The default template identifier for the reconcile/compare display.
// Note that the first reconcile template ID is 9010.
#define IDD_RECONDISPLAY     9000   // Device reconcile initial template
#define IDS_RECONDISPLAY     9001   // Reconcile DEVICE template name base
#define IDD_RECONPAGE        9002   // Device reconcile page holder template
#define IDD_RECON_PAGE         10   // Add to above for start of next page(s)
#define IDS_RECON_LABEL     11000   // ...to reconcile ID for tab label and

// Device offline-wizard display identifier offsets.
// Note that wizard display pages are numbered from 1...,j,...N.
#define IDS_OFFLINEWIZARD     449   // Config template name base string
#define IDD_OFFLINEWIZARD     450   // Device configuration initial template
#define IDD_OFFLINE_PAGE        1   // Add to above for start of page(s)
#define IDS_OFFLINE_TITLE      20   // ...to config ID for wizard title.


//////////////////////////////////////////////////////////////////////////////
// RECONCILE/COMPARE CONTROL IDs
// Defines the controls IDs of the column headers placed below the timer
// controls that label the parameter columns on the reconcile display.
#define ID_DEV_LABEL_LEFT     798
#define ID_DEV_LABEL_RIGHT    799

// Device resource DLL reconcile display button IDs
#define IDC_DEV_DEVICE_L2R    703   // Copy device to AMS database button ID.
#define IDC_DEV_DEVICE_R2L    704   // Copy AMS database to device button ID.                                    
                              


//////////////////////////////////////////////////////////////////////////////
// COMMON BUTTON IDs
// Device resource common button IDs needed on Hart Configure, Compare,  
// Status, or Process Variables.
#define ID_DEV_OK            IDOK   // Display's OK button ID
#define ID_DEV_CANCEL    IDCANCEL   // Display's Cancel button ID
#define ID_DEV_SEND        0xEA00   // Display's Apply button ID
#define ID_DEV_HELP        0xE147   // Display's Help button ID
#define ID_DEV_BACK            10   // Device-wizard 'Back' button
#define ID_DEV_FORWARD         11   // Device-wizard 'Forward' button


//////////////////////////////////////////////////////////////////////////////
// PARAMETER CONTROL IDs
// Device resource DLL common AMS parameter control IDs.
// Use these constants to ID the AMS parameter controls within each display.
// You should use them in TAB order, restarting at IDC_FMS_1 with
// each new display (i.e., the IDC_FMS_XX identifiers need only be unique
// within the current dialog template).
#define IDC_FMS_START         500
#define IDC_FMS_1             IDC_FMS_START + 1
#define IDC_FMS_2             IDC_FMS_START + 2
#define IDC_FMS_3             IDC_FMS_START + 3
#define IDC_FMS_4             IDC_FMS_START + 4
#define IDC_FMS_5             IDC_FMS_START + 5
#define IDC_FMS_6             IDC_FMS_START + 6
#define IDC_FMS_7             IDC_FMS_START + 7
#define IDC_FMS_8             IDC_FMS_START + 8
#define IDC_FMS_9             IDC_FMS_START + 9
#define IDC_FMS_10            IDC_FMS_START + 10
#define IDC_FMS_11            IDC_FMS_START + 11
#define IDC_FMS_12            IDC_FMS_START + 12
#define IDC_FMS_13            IDC_FMS_START + 13
#define IDC_FMS_14            IDC_FMS_START + 14
#define IDC_FMS_15            IDC_FMS_START + 15
#define IDC_FMS_16            IDC_FMS_START + 16
#define IDC_FMS_17            IDC_FMS_START + 17
#define IDC_FMS_18            IDC_FMS_START + 18
#define IDC_FMS_19            IDC_FMS_START + 19
#define IDC_FMS_20            IDC_FMS_START + 20
#define IDC_FMS_21            IDC_FMS_START + 21
#define IDC_FMS_22            IDC_FMS_START + 22
#define IDC_FMS_23            IDC_FMS_START + 23
#define IDC_FMS_24            IDC_FMS_START + 24
#define IDC_FMS_25            IDC_FMS_START + 25
#define IDC_FMS_26            IDC_FMS_START + 26
#define IDC_FMS_27            IDC_FMS_START + 27
#define IDC_FMS_28            IDC_FMS_START + 28
#define IDC_FMS_29            IDC_FMS_START + 29
#define IDC_FMS_30            IDC_FMS_START + 30
#define IDC_FMS_31            IDC_FMS_START + 31
#define IDC_FMS_32            IDC_FMS_START + 32
#define IDC_FMS_33            IDC_FMS_START + 33
#define IDC_FMS_34            IDC_FMS_START + 34
#define IDC_FMS_35            IDC_FMS_START + 35
#define IDC_FMS_36            IDC_FMS_START + 36
#define IDC_FMS_37            IDC_FMS_START + 37
#define IDC_FMS_38            IDC_FMS_START + 38
#define IDC_FMS_39            IDC_FMS_START + 39
#define IDC_FMS_40            IDC_FMS_START + 40
#define IDC_FMS_41            IDC_FMS_START + 41
#define IDC_FMS_42            IDC_FMS_START + 42
#define IDC_FMS_43            IDC_FMS_START + 43
#define IDC_FMS_44            IDC_FMS_START + 44
#define IDC_FMS_45            IDC_FMS_START + 45
#define IDC_FMS_46            IDC_FMS_START + 46
#define IDC_FMS_47            IDC_FMS_START + 47
#define IDC_FMS_48            IDC_FMS_START + 48
#define IDC_FMS_49            IDC_FMS_START + 49
#define IDC_FMS_50            IDC_FMS_START + 50
#define IDC_FMS_51            IDC_FMS_START + 51
#define IDC_FMS_52            IDC_FMS_START + 52
#define IDC_FMS_53            IDC_FMS_START + 53
#define IDC_FMS_54            IDC_FMS_START + 54
#define IDC_FMS_55            IDC_FMS_START + 55
#define IDC_FMS_56            IDC_FMS_START + 56
#define IDC_FMS_57            IDC_FMS_START + 57
#define IDC_FMS_58            IDC_FMS_START + 58
#define IDC_FMS_59            IDC_FMS_START + 59
#define IDC_FMS_60            IDC_FMS_START + 60
#define IDC_FMS_61            IDC_FMS_START + 61
#define IDC_FMS_62            IDC_FMS_START + 62
#define IDC_FMS_63            IDC_FMS_START + 63
#define IDC_FMS_64            IDC_FMS_START + 64
#define IDC_FMS_65            IDC_FMS_START + 65
#define IDC_FMS_66            IDC_FMS_START + 66
#define IDC_FMS_67            IDC_FMS_START + 67
#define IDC_FMS_68            IDC_FMS_START + 68
#define IDC_FMS_69            IDC_FMS_START + 69
#define IDC_FMS_70            IDC_FMS_START + 70
#define IDC_FMS_71            IDC_FMS_START + 71
#define IDC_FMS_72            IDC_FMS_START + 72
#define IDC_FMS_73            IDC_FMS_START + 73
#define IDC_FMS_74            IDC_FMS_START + 74
#define IDC_FMS_75            IDC_FMS_START + 75
#define IDC_FMS_76            IDC_FMS_START + 76
#define IDC_FMS_77            IDC_FMS_START + 77
#define IDC_FMS_78            IDC_FMS_START + 78
#define IDC_FMS_79            IDC_FMS_START + 79
#define IDC_FMS_80            IDC_FMS_START + 80
#define IDC_FMS_81            IDC_FMS_START + 81
#define IDC_FMS_82            IDC_FMS_START + 82
#define IDC_FMS_83            IDC_FMS_START + 83
#define IDC_FMS_84            IDC_FMS_START + 84
#define IDC_FMS_85            IDC_FMS_START + 85
#define IDC_FMS_86            IDC_FMS_START + 86
#define IDC_FMS_87            IDC_FMS_START + 87
#define IDC_FMS_88            IDC_FMS_START + 88
#define IDC_FMS_89            IDC_FMS_START + 89
#define IDC_FMS_90            IDC_FMS_START + 90
#define IDC_FMS_91            IDC_FMS_START + 91
#define IDC_FMS_92            IDC_FMS_START + 92
#define IDC_FMS_93            IDC_FMS_START + 93
#define IDC_FMS_94            IDC_FMS_START + 94
#define IDC_FMS_95            IDC_FMS_START + 95
#define IDC_FMS_96            IDC_FMS_START + 96
#define IDC_FMS_97            IDC_FMS_START + 97
#define IDC_FMS_98            IDC_FMS_START + 98
#define IDC_FMS_99            IDC_FMS_START + 99
#define IDC_FMS_100           IDC_FMS_START + 100
#define IDC_FMS_FINISH        IDC_FMS_100 + 1


//////////////////////////////////////////////////////////////////////////////
// RECONCILE/COMPARE PARAMETER CONTROL IDs
// Device resource DLL AMS 'clone' button control IDs for reconcile/compare display.
// Use these constants to ID the 'clone' buttons associated with the AMS
// parameter controls within the reconcile display.
// Place the control IDs such that the 'clone' button for IDC_FMS_X, 
// labelled as IDC_FMS_CLONE_X, is located next to the control that will 
// receive the data copied from the AMS parameter control to it's left or right.
#define IDC_FMS_CLONE_OFFSET  100
#define IDC_FMS_CLONE_START   600
#define IDC_FMS_CLONE_1       IDC_FMS_CLONE_START + 1
#define IDC_FMS_CLONE_2       IDC_FMS_CLONE_START + 2
#define IDC_FMS_CLONE_3       IDC_FMS_CLONE_START + 3
#define IDC_FMS_CLONE_4       IDC_FMS_CLONE_START + 4
#define IDC_FMS_CLONE_5       IDC_FMS_CLONE_START + 5
#define IDC_FMS_CLONE_6       IDC_FMS_CLONE_START + 6
#define IDC_FMS_CLONE_7       IDC_FMS_CLONE_START + 7
#define IDC_FMS_CLONE_8       IDC_FMS_CLONE_START + 8
#define IDC_FMS_CLONE_9       IDC_FMS_CLONE_START + 9
#define IDC_FMS_CLONE_10      IDC_FMS_CLONE_START + 10
#define IDC_FMS_CLONE_11      IDC_FMS_CLONE_START + 11
#define IDC_FMS_CLONE_12      IDC_FMS_CLONE_START + 12
#define IDC_FMS_CLONE_13      IDC_FMS_CLONE_START + 13
#define IDC_FMS_CLONE_14      IDC_FMS_CLONE_START + 14
#define IDC_FMS_CLONE_15      IDC_FMS_CLONE_START + 15
#define IDC_FMS_CLONE_16      IDC_FMS_CLONE_START + 16
#define IDC_FMS_CLONE_17      IDC_FMS_CLONE_START + 17
#define IDC_FMS_CLONE_18      IDC_FMS_CLONE_START + 18
#define IDC_FMS_CLONE_19      IDC_FMS_CLONE_START + 19
#define IDC_FMS_CLONE_20      IDC_FMS_CLONE_START + 20
#define IDC_FMS_CLONE_21      IDC_FMS_CLONE_START + 21
#define IDC_FMS_CLONE_22      IDC_FMS_CLONE_START + 22
#define IDC_FMS_CLONE_23      IDC_FMS_CLONE_START + 23
#define IDC_FMS_CLONE_24      IDC_FMS_CLONE_START + 24
#define IDC_FMS_CLONE_25      IDC_FMS_CLONE_START + 25
#define IDC_FMS_CLONE_26      IDC_FMS_CLONE_START + 26
#define IDC_FMS_CLONE_27      IDC_FMS_CLONE_START + 27
#define IDC_FMS_CLONE_28      IDC_FMS_CLONE_START + 28
#define IDC_FMS_CLONE_29      IDC_FMS_CLONE_START + 29
#define IDC_FMS_CLONE_30      IDC_FMS_CLONE_START + 30
#define IDC_FMS_CLONE_31      IDC_FMS_CLONE_START + 31
#define IDC_FMS_CLONE_32      IDC_FMS_CLONE_START + 32
#define IDC_FMS_CLONE_33      IDC_FMS_CLONE_START + 33
#define IDC_FMS_CLONE_34      IDC_FMS_CLONE_START + 34
#define IDC_FMS_CLONE_35      IDC_FMS_CLONE_START + 35
#define IDC_FMS_CLONE_36      IDC_FMS_CLONE_START + 36
#define IDC_FMS_CLONE_37      IDC_FMS_CLONE_START + 37
#define IDC_FMS_CLONE_38      IDC_FMS_CLONE_START + 38
#define IDC_FMS_CLONE_39      IDC_FMS_CLONE_START + 39
#define IDC_FMS_CLONE_40      IDC_FMS_CLONE_START + 40
#define IDC_FMS_CLONE_41      IDC_FMS_CLONE_START + 41
#define IDC_FMS_CLONE_42      IDC_FMS_CLONE_START + 42
#define IDC_FMS_CLONE_43      IDC_FMS_CLONE_START + 43
#define IDC_FMS_CLONE_44      IDC_FMS_CLONE_START + 44
#define IDC_FMS_CLONE_45      IDC_FMS_CLONE_START + 45
#define IDC_FMS_CLONE_46      IDC_FMS_CLONE_START + 46
#define IDC_FMS_CLONE_47      IDC_FMS_CLONE_START + 47
#define IDC_FMS_CLONE_48      IDC_FMS_CLONE_START + 48
#define IDC_FMS_CLONE_49      IDC_FMS_CLONE_START + 49
#define IDC_FMS_CLONE_50      IDC_FMS_CLONE_START + 50
#define IDC_FMS_CLONE_51      IDC_FMS_CLONE_START + 51
#define IDC_FMS_CLONE_52      IDC_FMS_CLONE_START + 52
#define IDC_FMS_CLONE_53      IDC_FMS_CLONE_START + 53
#define IDC_FMS_CLONE_54      IDC_FMS_CLONE_START + 54
#define IDC_FMS_CLONE_55      IDC_FMS_CLONE_START + 55
#define IDC_FMS_CLONE_56      IDC_FMS_CLONE_START + 56
#define IDC_FMS_CLONE_57      IDC_FMS_CLONE_START + 57
#define IDC_FMS_CLONE_58      IDC_FMS_CLONE_START + 58
#define IDC_FMS_CLONE_59      IDC_FMS_CLONE_START + 59
#define IDC_FMS_CLONE_60      IDC_FMS_CLONE_START + 60
#define IDC_FMS_CLONE_61      IDC_FMS_CLONE_START + 61
#define IDC_FMS_CLONE_62      IDC_FMS_CLONE_START + 62
#define IDC_FMS_CLONE_63      IDC_FMS_CLONE_START + 63
#define IDC_FMS_CLONE_64      IDC_FMS_CLONE_START + 64
#define IDC_FMS_CLONE_65      IDC_FMS_CLONE_START + 65
#define IDC_FMS_CLONE_66      IDC_FMS_CLONE_START + 66
#define IDC_FMS_CLONE_67      IDC_FMS_CLONE_START + 67
#define IDC_FMS_CLONE_68      IDC_FMS_CLONE_START + 68
#define IDC_FMS_CLONE_69      IDC_FMS_CLONE_START + 69
#define IDC_FMS_CLONE_70      IDC_FMS_CLONE_START + 70
#define IDC_FMS_CLONE_71      IDC_FMS_CLONE_START + 71
#define IDC_FMS_CLONE_72      IDC_FMS_CLONE_START + 72
#define IDC_FMS_CLONE_73      IDC_FMS_CLONE_START + 73
#define IDC_FMS_CLONE_74      IDC_FMS_CLONE_START + 74
#define IDC_FMS_CLONE_75      IDC_FMS_CLONE_START + 75
#define IDC_FMS_CLONE_76      IDC_FMS_CLONE_START + 76
#define IDC_FMS_CLONE_77      IDC_FMS_CLONE_START + 77
#define IDC_FMS_CLONE_78      IDC_FMS_CLONE_START + 78
#define IDC_FMS_CLONE_79      IDC_FMS_CLONE_START + 79
#define IDC_FMS_CLONE_80      IDC_FMS_CLONE_START + 80
#define IDC_FMS_CLONE_81      IDC_FMS_CLONE_START + 81
#define IDC_FMS_CLONE_82      IDC_FMS_CLONE_START + 82
#define IDC_FMS_CLONE_83      IDC_FMS_CLONE_START + 83
#define IDC_FMS_CLONE_84      IDC_FMS_CLONE_START + 84
#define IDC_FMS_CLONE_85      IDC_FMS_CLONE_START + 85
#define IDC_FMS_CLONE_86      IDC_FMS_CLONE_START + 86
#define IDC_FMS_CLONE_87      IDC_FMS_CLONE_START + 87
#define IDC_FMS_CLONE_88      IDC_FMS_CLONE_START + 88
#define IDC_FMS_CLONE_89      IDC_FMS_CLONE_START + 89
#define IDC_FMS_CLONE_90      IDC_FMS_CLONE_START + 90
#define IDC_FMS_CLONE_91      IDC_FMS_CLONE_START + 91
#define IDC_FMS_CLONE_92      IDC_FMS_CLONE_START + 92
#define IDC_FMS_CLONE_93      IDC_FMS_CLONE_START + 93
#define IDC_FMS_CLONE_94      IDC_FMS_CLONE_START + 94
#define IDC_FMS_CLONE_95      IDC_FMS_CLONE_START + 95
#define IDC_FMS_CLONE_96      IDC_FMS_CLONE_START + 96
#define IDC_FMS_CLONE_97      IDC_FMS_CLONE_START + 97
#define IDC_FMS_CLONE_98      IDC_FMS_CLONE_START + 98
#define IDC_FMS_CLONE_99      IDC_FMS_CLONE_START + 99
#define IDC_FMS_CLONE_100     IDC_FMS_CLONE_START + 100
#define IDC_FMS_CLONE_FINISH  IDC_FMS_CLONE_100 + 1

// The offset to the matching AMS parameter control in the reconcile display
// (Hart only) IDC_FMS_X + IDC_FMS_BUDDY will yield the same parameter in 
// the database as in the actual device.
#define IDC_FMS_BUDDY         50

///////////////////////////////////////////////////////////////////////////////
// MENU COMMAND AND MENU STRING IDs
// General menu command IDs.
#define	 CM_SCAN_MULTIPLEXER 0x8287		// Scan all devices below this multiplexer
#define	 CM_SCAN_NEW_MULTIPLEXER 0x8288 // Scan all new devices below this multiplexer

// Method menu command IDs (to make it easier to use in the resource editor)
#define  CM_METHODS			0x8300  
#define  CM_METHOD1        CM_METHODS
#define  CM_METHOD2        (CM_METHODS + 1)
#define  CM_METHOD3        (CM_METHODS + 2)
#define  CM_METHOD4        (CM_METHODS + 3)
#define  CM_METHOD5        (CM_METHODS + 4)
#define  CM_METHOD6        (CM_METHODS + 5)
#define  CM_METHOD7        (CM_METHODS + 6)
#define  CM_METHOD8        (CM_METHODS + 7)
#define  CM_METHOD9        (CM_METHODS + 8)
#define  CM_METHOD10       (CM_METHODS + 9)
#define  CM_METHOD11       (CM_METHODS + 10)
#define  CM_METHOD12       (CM_METHODS + 11)
#define  CM_METHOD13       (CM_METHODS + 12)
#define  CM_METHOD14       (CM_METHODS + 13)
#define  CM_METHOD15       (CM_METHODS + 14)
#define  CM_METHOD16       (CM_METHODS + 15)
#define  CM_METHOD17       (CM_METHODS + 16)
#define  CM_METHOD18       (CM_METHODS + 17)
#define  CM_METHOD19       (CM_METHODS + 18)
#define  CM_METHOD20       (CM_METHODS + 19)
#define  CM_METHOD21       (CM_METHODS + 20)
#define  CM_METHOD22       (CM_METHODS + 21)
#define  CM_METHOD23       (CM_METHODS + 22)
#define  CM_METHOD24       (CM_METHODS + 23)
#define  CM_METHOD25       (CM_METHODS + 24)
#define  CM_METHODS_LAST	0x837F			// End of method menu IDs.

// Method Help string IDs (to make it easier to use in the resource editor)
#define  IDS_METHODS		0x8380
#define  IDS_METHOD1       IDS_METHODS
#define  IDS_METHOD2       (IDS_METHODS + 1)
#define  IDS_METHOD3       (IDS_METHODS + 2)
#define  IDS_METHOD4       (IDS_METHODS + 3)
#define  IDS_METHOD5       (IDS_METHODS + 4)
#define  IDS_METHOD6       (IDS_METHODS + 5)
#define  IDS_METHOD7       (IDS_METHODS + 6)
#define  IDS_METHOD8       (IDS_METHODS + 7)
#define  IDS_METHOD9       (IDS_METHODS + 8)
#define  IDS_METHOD10      (IDS_METHODS + 9)
#define  IDS_METHOD11      (IDS_METHODS + 10)
#define  IDS_METHOD12      (IDS_METHODS + 11)
#define  IDS_METHOD13      (IDS_METHODS + 12)
#define  IDS_METHOD14      (IDS_METHODS + 13)
#define  IDS_METHOD15      (IDS_METHODS + 14)
#define  IDS_METHOD16      (IDS_METHODS + 15)
#define  IDS_METHOD17      (IDS_METHODS + 16)
#define  IDS_METHOD18      (IDS_METHODS + 17)
#define  IDS_METHOD19      (IDS_METHODS + 18)
#define  IDS_METHOD20      (IDS_METHODS + 19)
#define  IDS_METHOD21      (IDS_METHODS + 20)
#define  IDS_METHOD22      (IDS_METHODS + 21)
#define  IDS_METHOD23      (IDS_METHODS + 22)
#define  IDS_METHOD24      (IDS_METHODS + 23)
#define  IDS_METHOD25      (IDS_METHODS + 24)

// Snap-on context menu IDs
#define  CM_SNAP_ON_RC			0x8480
#define  CM_SNAP_ON_RC_LAST		0x84BF

// Define Pre commit methods.  These are used to specifiy user methods that need
// to be invoked before doing a commit.  The rc file is modified to specify the
// IDS_PRECOMMIT_XX value as well as a ; separated param name and method name.
#define IDS_PRECOMMIT_0       500
#define IDS_PRECOMMIT_1       501
#define IDS_PRECOMMIT_2       502
#define IDS_PRECOMMIT_3       503
#define IDS_PRECOMMIT_4       504
#define IDS_PRECOMMIT_5       505
#define IDS_PRECOMMIT_6       506
#define IDS_PRECOMMIT_7       507
#define IDS_PRECOMMIT_8       508
#define IDS_PRECOMMIT_9       509
#define IDS_PRECOMMIT_10      510
#define IDS_PRECOMMIT_11      511
#define IDS_PRECOMMIT_12      512
#define IDS_PRECOMMIT_13      513
#define IDS_PRECOMMIT_14      514
#define IDS_PRECOMMIT_15      515
#define IDS_PRECOMMIT_16      516
#define IDS_PRECOMMIT_17      517
#define IDS_PRECOMMIT_18      518
#define IDS_PRECOMMIT_19      519
#define IDS_POSTCOMMIT_0       520
#define IDS_POSTCOMMIT_1       521
#define IDS_POSTCOMMIT_2       522
#define IDS_POSTCOMMIT_3       523
#define IDS_POSTCOMMIT_4       524
#define IDS_POSTCOMMIT_5       525
#define IDS_POSTCOMMIT_6       526
#define IDS_POSTCOMMIT_7       527
#define IDS_POSTCOMMIT_8       528
#define IDS_POSTCOMMIT_9       529
#define IDS_POSTCOMMIT_10      530
#define IDS_POSTCOMMIT_11      531
#define IDS_POSTCOMMIT_12      532
#define IDS_POSTCOMMIT_13      533
#define IDS_POSTCOMMIT_14      534
#define IDS_POSTCOMMIT_15      535
#define IDS_POSTCOMMIT_16      536
#define IDS_POSTCOMMIT_17      537
#define IDS_POSTCOMMIT_18      538
#define IDS_POSTCOMMIT_19      539

#define DEV_MAX_COMMIT_OBJECTS    20


///////////////////////////////////////////////////////////////////////////////
// INDEPENDENT VARIABLE PARAMETERS
// Independent Variable Parameters (string table IDs) and their matching
// help strings.  Each IDS_IVP_XXX defines a parameter name that corresponds
// to a key independent variable within the given device.  These parameters
// are used to resolve some of the remaining dependent variables within
// the device; these IVPs must contain run-time values for the device
// display to properly initialize and are particularly important in the 
// case of offline (database) representations of the given device.
// Each parameter name you define with a string table entry ID will be
// initialized, one at a time (in order) via a device wizard display, in the
// offline database before the remaining device is displayed via any of
// the stock device displays (e.g., configuration properties).
// Help strings, for the given parameters, are defined as 
// IDS_IVP_X + DEV_IVP_HELP_OFFSET (e.g., help for IDS_IVP_0 == 420).
#define IDS_IVP_0             400
#define IDS_IVP_1             401
#define IDS_IVP_2             402
#define IDS_IVP_3             403
#define IDS_IVP_4             404
#define IDS_IVP_5             405
#define IDS_IVP_6             406
#define IDS_IVP_7             407
#define IDS_IVP_8             408
#define IDS_IVP_9             409
#define IDS_IVP_10            410
#define IDS_IVP_11            411
#define IDS_IVP_12            412
#define IDS_IVP_13            413
#define IDS_IVP_14            414
#define IDS_IVP_15            415
#define IDS_IVP_16            416
#define IDS_IVP_17            417
#define IDS_IVP_18            418
#define IDS_IVP_19            419
#define DEV_MAX_IVP            20
#define DEV_IVP_HELP_OFFSET    20


///////////////////////////////////////////////////////////////////////////////
// PRIMARY VALIDITY VARIABLES
// Defines the transmitter mode 'primary validity variables'.  Each string
// ID defines a parameter moniker that is tested for validity at run-time
// and sets the 'mode' for a device.  When loading display templates, the
// mode index determines which dialog templates to load for each page
// of a tabbed display (i.e., _10, _11, et al.). There are ten possible
// transmitter modes.
#define IDS_PVV_0             900
#define IDS_PVV_1             901
#define IDS_PVV_2             902
#define IDS_PVV_3             903
#define IDS_PVV_4             904
#define IDS_PVV_5             905
#define IDS_PVV_6             906
#define IDS_PVV_7             907
#define IDS_PVV_8             908
#define IDS_PVV_9             909
#define DEV_MAX_MODES          10



/***************************************************************************
THE DEFINES BELOW THIS LINE ARE EITHER DEPRECATED OR FOR AMS INTERNAL 
USE ONLY.  DEVICE DEVELOPERS - DO NOT USE!!!
***************************************************************************/



// Generic device resource IDs
#define IDS_DEVICE_HELP       106   // Device specific help file name
#define IDS_BLOCK_HELP        107   // Block specific help file name

// Device About Dialog-box identifiers
#define IDD_DEVICE_ABOUT	  199   // Default device aboutbox

// Defines the control ID of the progress indicator used during long
// device operations (e.g., Device Transfer)
#define ID_DEV_PROGRESS       794

// Defines the control ID of the Timer Control(s) embedded within
// the various tabbed displays.
#define ID_DEV_TIMER          795
#define ID_DEV_TIMER_LEFT     796
#define ID_DEV_TIMER_RIGHT    797

// Defines the control ID of the tab control within the configuration
// and reconcile displays.  Make sure this value is unique within the
// display (i.e., NOT equal to any common dialog button IDs and larger
// than a reasonable number of ID_FMS_XX control identifiers within the
// device resource script's resource.h).
#define ID_DEV_TAB            800

// Defines the control IDs of the tab views within the configuration
// and reconcile displays.  Make sure these values are unique within the
// display (i.e., NOT equal to any common dialog button IDs and larger
// than a reasonable number of ID_FMS_XX control identifiers within the
// device resource script's resource.h).
#define ID_DEV_TAB_VIEW       801
#define ID_DEV_TAB_VIEW_LAST  899

// Positioning constants (in dialog units) used for layout in the
// tabbed dialog displays (property sheets).
#define DEV_PRPRTY_LEADING      5   // Space between top of config client
                                    // area and top of tab control(s)
#define DEV_TAB_LEADING         5   // Space between bottom of tab control and
                                    // top of associated tab view.
#define DEV_PRPRTY_INDENT       5   // Space between left edge of config client
                                    // area and left of tab view client area.
#define DEV_TAB_INDENT          5   // Horz. Space between left edge of tab
                                    // client area and left edge of tab view.

#define IDS_SNAP_ON_FIRST_NAME	13000	//first name of snap ons

// Positioning constants (in dialog units) used specifically for layout
// within the reconcile display.
#define DEV_RECON_LEADING      20   // Space between top of recon form client
                                    // area and bottom of tab control(s)
#define DEV_RECON_INDENT        5   // Space between left edge of recon client
                                    // area and left of form view client area.
#define DEV_RECON_BOTTOM       25   // Space between bottom edge of form view
                                    // client and bottom edge of recon client
                                    // (save space for buttons and the 
                                    // progress indicator).
#define DEV_RECON_CAP_LEN     125   // Length (in dialog units based on MS Sans
                                    // Serif 8) of the Recon progress caption.
#define DEV_RECON_PROG_LEN    200   // Length (in dialog units based on MS Sans
                                    // Serif 8) of the Recon progress control.

// Positioning constants (in dialog units) used specifically for layout
// within the wizard display.
#define DEV_WIZ_LEADING         0   // Space between top of wizard form client
                                    // area and bottom of wizard titlebar.
#define DEV_WIZ_INDENT          7   // Space between left edge of wizard client
                                    // area and left of wiz-view client area.
#define DEV_WIZ_BOTTOM         28   // Space between bottom edge of wiz view
                                    // client and bottom edge of wizard client
                                    // (save space for buttons and the edge.

// Device context popup menu IDs
#define IDM_DEVICE            800   // Device context popup menu resource
#define  CM_DEFAULT			0x8200  // Default device popup menu option
#define  CM_FACEPLATE		0x8210  // Faceplate command menu item
#define  CM_STATUSDISPLAY	0x8220  // Status display command menu item
#define  CM_DEV_ASSIGN		0x8225  // Assign off-line device
#define  CM_DEV_RENAME		0x8226  // Rename device
#define  CM_DEV_DELETE		0x8227  // Delete a device
#define  CM_SERVICE_NOTES	0x8230  // Device service notes menu command
#define  CM_LOG_VIEWER		0x8240  // Device log viewer menu command
#define  CM_DEV_MANUAL_EVENT 0x8241  // Record manual event menu command
#define  CM_FOUND_AS_LEFT	0x8245  // Device 'as found as left' command
#define  CM_DATA_RECONCILE	0x8250  // Database reconcile menu command
#define  CM_DEVICE_HELP		0x8260  // Device information help command
#define  CM_DEVICE_ABOUT	0x8270  // Device information menu command
#define  CM_PROPERTIES		0x8280  // Device configuration view menu command
#define  CM_TEST_DEF        0x8281	// Test definition menu command
#define  CM_CALIB_STATUS    0x8282	// Calibration status menu command
#define  CM_CALIB_HISTORY   0x8283	// Calibration history menu command
#define  CM_TEST_DATA_ENTRY 0x8284	// Test data entry menu command
#define  CM_CLEAR_OFFLINE   0x8290	// Clear the offline configuration
#define  CM_SCAN_DEVICE		0x8291  // Scan all properties for device

// Device specific snap-on function command IDs.
// Legacy integrated ValveLink SNAP-ON
#define  CM_SNAP_ON				0x8400
#define  CM_SNAP_ON_LAST		0x843F

// Command line execution snap-on command IDs
// Command CM_SNAP_ON_EXEx will result in the execution of the string defined by
// IDS_SNAP_ON_EXEx as a command line.
#define CM_SNAP_ON_EXE			CM_SNAP_ON
#define CM_SNAP_ON_EXE1			CM_SNAP_ON_EXE
#define CM_SNAP_ON_EXE2			(CM_SNAP_ON_EXE + 1)
#define CM_SNAP_ON_EXE3			(CM_SNAP_ON_EXE + 2)
#define CM_SNAP_ON_EXE4			(CM_SNAP_ON_EXE + 3)
#define CM_SNAP_ON_EXE5			(CM_SNAP_ON_EXE + 4)
#define CM_SNAP_ON_EXE_LAST		(CM_SNAP_ON_EXE + 15)	// Arbitrary

// Snap-on menu commands may be divided into subsets, according to the action
// to be taken when the menu item is selected.
#define IDS_SNAP_ON				0x8480	
#define IDS_SNAP_ON_EXE			IDS_SNAP_ON
#define IDS_SNAP_ON_EXE1		IDS_SNAP_ON_EXE
#define IDS_SNAP_ON_EXE2		(IDS_SNAP_ON_EXE + 1)
#define IDS_SNAP_ON_EXE3		(IDS_SNAP_ON_EXE + 2)
#define IDS_SNAP_ON_EXE4		(IDS_SNAP_ON_EXE + 3)
#define IDS_SNAP_ON_EXE5		(IDS_SNAP_ON_EXE + 4)
#define IDS_SNAP_ON_EXE_LAST	(IDS_SNAP_ON_EXE + 15)	// Arbitrary

// Dynamically added to device context Snap-On pop-down menu
#define  CM_SNAP_ON_INI			0x8440
#define  CM_SNAP_ON_INI_LAST	0x847F

// Device/Block context popup menu IDs for Fieldbus devices only
#define  CM_DEVICE_CONFIG_DISPLAY	0x8221	// Device Configure menu item command
#define	 CM_DEVICE_COMPARE_DISPLAY	0x8222	// Device Compare menu item command 
#define  CM_DEVICE_AUDIT_TRAIL		0x8223	// Device Audit Trail menu item command
#define  CM_CONFIGDISPLAY			0x8280	// Block Configure menu item command


//////////////////////////////////////////////////////////////////////////////
// Device resource DLL reconcile display IDs
#define IDC_DEV_PAGE_L2R      701   // Copy current TAB page to AMS database.
#define IDC_DEV_PAGE_R2L      702   // Copy AMS database to current TAB view.
                              
//////////////////////////////////////////////////////////////////////////////
// Device view resource definitions used to optimize layout from DD
// Note that all coordinates are in dialog units and are relative to the 
// parent window (i.e., values reflect those values that are stored in the
// device resource script.

// Faceplate
#define IDD_FACEPLATE_CX            428 // Horiz. width of faceplate template
#define IDD_FACEPLATE_CY            240 // Vert. length of faceplate template
#define IDD_FACEPLATE_CLOSE_X       315 // Upper left X of Close button
#define IDD_FACEPLATE_CLOSE_Y       216 // Upper left Y of Close button
#define IDD_FACEPLATE_CLOSE_CX       50 // Width of Close button
#define IDD_FACEPLATE_CLOSE_CY       14 // Height of Close button
#define IDD_FACEPLATE_HELP_X        369 // Upper left X of Help button
#define IDD_FACEPLATE_HELP_Y        216 // Upper left Y of Help button
#define IDD_FACEPLATE_HELP_CX        50 // Width of Help button
#define IDD_FACEPLATE_HELP_CY        14 // Height of Help button

// Status Display
#define IDD_STATUSDISPLAY_CX        428 // Horiz. width of status template
#define IDD_STATUSDISPLAY_CY        240 // Vert. length of status template
#define IDD_STATUSPAGE_CX           408 // Horiz. width of status template
#define IDD_STATUSPAGE_CY           188 // Vert. len - single row of tabs
#define IDD_STATUSPAGE_CY_2         180 // Vert. len - double row of tabs
#define IDD_STATUSPAGE_CY_3         172 // Vert. len - triple row of tabs
#define IDD_STATUSBIT_CX            192 // Horz. width of a single status bit
#define IDD_STATUSBIT_CY             13 // Vert. length of a single status bit
#define IDD_STATUSBIT_LEFT_X1         7 // X of first control (left column)
#define IDD_STATUSBIT_LEFT_X2       212 // X of first control (right column)
#define IDD_STATUSBIT_TOP_Y1          5 // Y of first control (both columns)
#define IDD_STATUSBIT_TOP_OFFSET     17 // Y offset to following control(s)
#define IDD_STATUSBIT_MAX_ROWS       10 // Maximum number of status bit rows
#define IDD_STATUSBIT_MAX_CHARS      45 // Maximum number of chars in status
#define IDD_STATUSDISPLAY_CLOSE_X   315 // Upper left X of Close button
#define IDD_STATUSDISPLAY_CLOSE_Y   216 // Upper left Y of Close button
#define IDD_STATUSDISPLAY_CLOSE_CX   50 // Width of Close button
#define IDD_STATUSDISPLAY_CLOSE_CY   14 // Height of Close button
#define IDD_STATUSDISPLAY_HELP_X    369 // Upper left X of Help button
#define IDD_STATUSDISPLAY_HELP_Y    216 // Upper left Y of Help button
#define IDD_STATUSDISPLAY_HELP_CX    50 // Width of Help button
#define IDD_STATUSDISPLAY_HELP_CY    14 // Height of Help button

// Configuration Display
#define IDD_CONFIGDISPLAY_CX        428 // Horiz. width of config template
#define IDD_CONFIGDISPLAY_CY        240 // Vert. length of config template
#define IDD_CONFIGPAGE_CX           408 // Horiz. width of config template
#define IDD_CONFIGPAGE_CY           188 // Vert. len - single row of tabs
#define IDD_CONFIGPAGE_CY_2         180 // Vert. len - double row of tabs
#define IDD_CONFIGPAGE_CY_3         172 // Vert. len - triple row of tabs
#define IDD_CONFIGDISPLAY_OK_X      207 // Upper left X of OK button
#define IDD_CONFIGDISPLAY_OK_Y      216 // Upper left Y of OK button
#define IDD_CONFIGDISPLAY_OK_CX      50 // Width of OK button
#define IDD_CONFIGDISPLAY_OK_CY      14 // Height of OK button
#define IDD_CONFIGDISPLAY_CANCEL_X  261 // Upper left X of Cancel button
#define IDD_CONFIGDISPLAY_CANCEL_Y  216 // Upper left Y of Cancel button
#define IDD_CONFIGDISPLAY_CANCEL_CX  50 // Width of Close button
#define IDD_CONFIGDISPLAY_CANCEL_CY  14 // Height of Close button
#define IDD_CONFIGDISPLAY_APPLY_X   315 // Upper left X of Apply button
#define IDD_CONFIGDISPLAY_APPLY_Y   216 // Upper left Y of Apply button
#define IDD_CONFIGDISPLAY_APPLY_CX   50 // Width of Apply button
#define IDD_CONFIGDISPLAY_APPLY_CY   14 // Height of Apply button
#define IDD_CONFIGDISPLAY_HELP_X    369 // Upper left X of Help button
#define IDD_CONFIGDISPLAY_HELP_Y    216 // Upper left Y of Help button
#define IDD_CONFIGDISPLAY_HELP_CX    50 // Width of Help button
#define IDD_CONFIGDISPLAY_HELP_CY    14 // Height of Help button

// Reconcile Display
#define IDD_RECONDISPLAY_CX         428 // Horiz. width of reconcile template
#define IDD_RECONDISPLAY_CY         240 // Vert. length of reconcile template
#define IDD_RECONPAGE_CX            408 // Horiz. width of reconcile template
#define IDD_RECONPAGE_CY            188 // Vert. len - single row of tabs
#define IDD_RECONPAGE_CY_2          180 // Vert. len - double row of tabs
#define IDD_RECONPAGE_CY_3          172 // Vert. len - triple row of tabs
#define IDD_RECONPARAM_CX           402 // Recommended width of parameter 
                                        // IDD_RECONDISPLAY_XX templates
#define IDD_RECONDEVICE_L2R_X       162 // Upper left X of device transfer L2R
#define IDD_RECONDEVICE_L2R_Y       216 // Upper left Y of device transfer L2R
#define IDD_RECONDEVICE_R2L_X       135 // Upper left X of device transfer R2L
#define IDD_RECONDEVICE_R2L_Y       216 // Upper left Y of device transfer R2L
#define IDD_RECONDEVICE_TEXT_X       17 // Coordinates for static text 
#define IDD_RECONDEVICE_TEXT_Y      217 // ...describing Device Transfer.
#define IDD_RECONDEVICE_TEXT_CX     107
#define IDD_RECONDEVICE_TEXT_CY      11
#define IDD_RECONPAGE_L2R_X         208 // Upper left X of device transfer L2R
#define IDD_RECONPAGE_L2R_Y         168 // Upper left Y of device transfer L2R
#define IDD_RECONPAGE_R2L_X         183 // Upper left X of device transfer R2L
#define IDD_RECONPAGE_R2L_Y         168 // Upper left Y of device transfer R2L
#define IDD_RECONPAGE_TEXT_X         81 // Coordinates for static text 
#define IDD_RECONPAGE_TEXT_Y        171 // ...describing Page Transfer.
#define IDD_RECONPAGE_TEXT_CX        97
#define IDD_RECONPAGE_TEXT_CY        11
#define IDD_RECON_TRANSFER_CX        20 // Width transfer buttons
#define IDD_RECON_TRANSFER_CY        14 // Height of transfer buttons
#define IDD_RECONDISPLAY_OK_X       207 // Upper left X of OK button
#define IDD_RECONDISPLAY_OK_Y       216 // Upper left Y of OK button
#define IDD_RECONDISPLAY_OK_CX       50 // Width of OK button
#define IDD_RECONDISPLAY_OK_CY       14 // Height of OK button
#define IDD_RECONDISPLAY_CANCEL_X   261 // Upper left X of Cancel button
#define IDD_RECONDISPLAY_CANCEL_Y   216 // Upper left Y of Cancel button
#define IDD_RECONDISPLAY_CANCEL_CX   50 // Width of Close button
#define IDD_RECONDISPLAY_CANCEL_CY   14 // Height of Close button
#define IDD_RECONDISPLAY_APPLY_X    315 // Upper left X of Apply button
#define IDD_RECONDISPLAY_APPLY_Y    216 // Upper left Y of Apply button
#define IDD_RECONDISPLAY_APPLY_CX    50 // Width of Apply button
#define IDD_RECONDISPLAY_APPLY_CY    14 // Height of Apply button
#define IDD_RECONDISPLAY_HELP_X     369 // Upper left X of Help button
#define IDD_RECONDISPLAY_HELP_Y     216 // Upper left Y of Help button
#define IDD_RECONDISPLAY_HELP_CX     50 // Width of Help button
#define IDD_RECONDISPLAY_HELP_CY     14 // Height of Help button

//////////////////////////////////////////////////////////////////////////////
// Device resource DLL entry-points are defined as "C" functions
// of the following types.
#if defined _WINDOWS || defined RC_INVOKED

interface IAMSDevice ;

// Initializes the device DLL's internals.
typedef BOOL (WINAPI* DEV_INITPROC)(void);
static const TCHAR* FMSDEVINIT = _T("InitProcedure");

// Set the device DLL's Block Moniker.
typedef VOID (WINAPI* DEV_BLKMON) (const long, LPCTSTR);
static const TCHAR* FMSDEVBLKMON = _T("SetBlockMoniker");

// Set the device DLL's Block Moniker for the Left Half of the Reconcile Screen
typedef VOID (WINAPI* DEV_LEFTBLKMON) (const long, LPCTSTR);
static const TCHAR* FMSDEVLEFTBLKMON = _T("SetLeftReconcileBlockMoniker");

// Set the device DLL's Block Moniker for the Right Half of the Reconcile Screen
typedef VOID (WINAPI* DEV_RIGHTBLKMON) (const long, LPCTSTR);
static const TCHAR* FMSDEVRIGHTBLKMON = _T("SetRightReconcileBlockMoniker");

// Returns the device DLL's block bitmap.
typedef HBITMAP (WINAPI* DEV_BITMAPPROC)(void);
static const TCHAR* FMSDEVBITMAP = _T("GetBlockBitmap");

typedef HICON (WINAPI* DEV_ICONPROC)(void);
static const TCHAR* FMSDEVICON = _T("GetBlockIcon");
typedef HICON (WINAPI* DEV_ICONPROCEX)(IAMSDevice *, IUnknown **);
static const TCHAR* FMSDEVICONEX = _T("GetBlockIconEx");

// Handles command messages routed to the device DLL by the device views.
typedef BOOL (WINAPI* DEV_CMDMSGPROC)(UINT, int, void*, AFX_CMDHANDLERINFO*);
static const TCHAR* FMSDEVHANDLEMSG = _T("HandleCmdMsg");

// Handles command messages routed to the device DLL by the device views.
typedef BOOL (WINAPI* DEV_CMDMSGPROCEX)(IAMSDevice *, LPCTSTR, UINT, int, void*, AFX_CMDHANDLERINFO*);
static const TCHAR* FMSDEVHANDLEMSGEX = _T("HandleCmdMsgEx");

// Returns Snap-On specific WinHelp context IDs.
typedef ULONG (WINAPI* DEV_CTRLHELPPROC)(UINT);
static const TCHAR* FMSDEVCTRLHELP = _T("ContextIDFromCtrl");

typedef ULONG (WINAPI* DEV_MENUHELPPROC)(UINT);
static const TCHAR* FMSDEVMENUHELP = _T("ContextIDFromMenu");


//////////////////////////////////////////////////////////////////////////////
// Device view resource definitions used internally by the device view 
// management classes.

// Windows brush used to paint the dialog view embedded within the device
// view frame; this brush is also used as the default background brush
// for the MDI child frame (the device view frame).
#define  DEV_BKBRUSH       COLOR_BTNFACE

// Windows brush used to paint the scrolling form view embedded within the
// tabbed device views (e.g., scrolling AMS control window within the 
// reconcile display).
#define  DEV_FORMBRUSH     COLOR_APPWORKSPACE

// Windows brush used to paint the client areas of the controls embedded within
// the device views (i.e., the editable areas of the edit controls, bit-
// enumerated controls, and listboxes).
#define  DEV_EDBRUSH       COLOR_WINDOW

// Text used for the individual copy buttons within the reconcile display.
static const TCHAR* STRLEFTCOPY     = _T("<<");
static const TCHAR* STRRIGHTCOPY    = _T(">>");
static const TCHAR* STRNOVALUE      = _T("*");
static const TCHAR* STRNOUNITS      = _T("/");
static const TCHAR* STRERROR        = _T("?");

#endif // #if defined _WINDOWS || defined RC_INVOKED

#endif // #ifndef __FMSDEVRC_H

// -- End of module: $RCSfile: fmsdevrc.h $ --
